==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/java.source/src/org/netbeans/modules/java/classfile/SideBarFactoryImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development and
 * Distribution License("CDDL") (collectively, the "License"). You may not use
 * this file except in compliance with the License. You can obtain a copy of
 * the License at http://www.netbeans.org/cddl-gplv2.html or
 * nbbuild/licenses/CDDL-GPL-2-CP. See the License for the specific language
 * governing permissions and limitations under the License. When distributing
 * the software, include this License Header Notice in each file and include
 * the License file at nbbuild/licenses/CDDL-GPL-2-CP. Oracle designates this
 * particular file as subject to the "Classpath" exception as provided by
 * Oracle in the GPL Version 2 section of the License file that accompanied
 * this code. If applicable, add the following below the License Header, with
 * the fields enclosed by brackets [] replaced by your own identifying
 * information: "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license." If you do not indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to its
 * licensees as provided above. However, if you add GPL Version 2 code and
 * therefore, elected the GPL Version 2 license, then the option applies only
 * if the new code is made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2011 Sun Microsystems, Inc.
 */
package org.netbeans.modules.java.classfile;

import java.net.URL;
import javax.swing.JComponent;
import javax.swing.text.Document;
import javax.swing.text.JTextComponent;
import org.netbeans.editor.SideBarFactory;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileStateInvalidException;
import org.openide.loaders.DataObject;
import org.openide.util.Exceptions;

/**
 *
 * @author lahvac
 */
public class SideBarFactoryImpl implements SideBarFactory {

    @Override
    public JComponent createSideBar(JTextComponent target) {
        Document doc = target.getDocument();
        FileObject originFile;
        Object origin = doc.getProperty(Document.StreamDescriptionProperty);

        if (origin instanceof DataObject) {
            originFile = ((DataObject) origin).getPrimaryFile();
        } else if (origin instanceof FileObject) {
            originFile = (FileObject) origin;
        } else {
            originFile = null;
        }

        Object classFileRoot;
        Object binaryName;
        if (originFile != null) {
            classFileRoot = originFile.getAttribute(CodeGenerator.CLASSFILE_ROOT);
            binaryName = originFile.getAttribute(CodeGenerator.CLASSFILE_BINNAME);
        } else {
            classFileRoot = binaryName = null;
        }

        if (classFileRoot instanceof URL && binaryName instanceof String) {
            try {
                return new AttachSourcePanel(
                    (URL) classFileRoot,
                    originFile.getURL(),
                    (String) binaryName);
            } catch (FileStateInvalidException ex) {
                Exceptions.printStackTrace(ex);
            }
        }
        return null;
    }

}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/java.source/src/org/netbeans/modules/java/classfile/SideBarFactoryImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development and
 * Distribution License("CDDL") (collectively, the "License"). You may not use
 * this file except in compliance with the License. You can obtain a copy of
 * the License at http://www.netbeans.org/cddl-gplv2.html or
 * nbbuild/licenses/CDDL-GPL-2-CP. See the License for the specific language
 * governing permissions and limitations under the License. When distributing
 * the software, include this License Header Notice in each file and include
 * the License file at nbbuild/licenses/CDDL-GPL-2-CP. Oracle designates this
 * particular file as subject to the "Classpath" exception as provided by
 * Oracle in the GPL Version 2 section of the License file that accompanied
 * this code. If applicable, add the following below the License Header, with
 * the fields enclosed by brackets [] replaced by your own identifying
 * information: "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license." If you do not indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to its
 * licensees as provided above. However, if you add GPL Version 2 code and
 * therefore, elected the GPL Version 2 license, then the option applies only
 * if the new code is made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2011 Sun Microsystems, Inc.
 */
package org.netbeans.modules.java.classfile;

import java.net.URL;
import javax.swing.JComponent;
import javax.swing.text.Document;
import javax.swing.text.JTextComponent;
import org.netbeans.editor.SideBarFactory;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileStateInvalidException;
import org.openide.loaders.DataObject;
import org.openide.util.Exceptions;

/**
 *
 * @author lahvac
 */
public class SideBarFactoryImpl implements SideBarFactory {

    @Override
    public JComponent createSideBar(JTextComponent target) {
        Document doc = target.getDocument();
        FileObject originFile;
        Object origin = doc.getProperty(Document.StreamDescriptionProperty);

        if (origin instanceof DataObject) {
            originFile = ((DataObject) origin).getPrimaryFile();
        } else if (origin instanceof FileObject) {
            originFile = (FileObject) origin;
        } else {
            originFile = null;
        }

        Object classFileRoot;
        Object binaryName;
        if (originFile != null) {
            classFileRoot = originFile.getAttribute(CodeGenerator.CLASSFILE_ROOT);
            binaryName = originFile.getAttribute(CodeGenerator.CLASSFILE_BINNAME);
        } else {
            classFileRoot = binaryName = null;
        }

        if (classFileRoot instanceof URL && binaryName instanceof String) {
            return new AttachSourcePanel(
                (URL) classFileRoot,
                originFile.toURL(),
                (String) binaryName);
        }
        return null;
    }

}
